==> koncd-0.7.1.tar.gz: koncd-0.7.1/koncd/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : Don Mr  1 19:38:27 CET 2001
    copyright            : (C) 2001 by Kai Heitkamp
    email                : koncd@kai-heitkamp.de
 ***************************************************************************/


#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>

#include "koncd.h"

static const char *description = I18N_NOOP("KOnCD - burn your own cd's");
	
static KCmdLineOptions options[] = {
  { 0, 0, 0 }
};

int main(int argc, char *argv[]) {

  KAboutData aboutData( "koncd",
                        I18N_NOOP("KOnCD"),
                        VERSION,
                        description,
                        KAboutData::License_GPL,
                        I18N_NOOP("Developed and Copyright 2000-2001 by Kai Heitkamp"),
                        I18N_NOOP("KOnCD is a frontend to cdrecord and mkisofs, that allows you to master CDs,\n"
																	"create multisession CDs, bootable CDs and supports blanking on CD-RW. It copy\n"
																	"CDs on-the-fly and supports disk at one mode and the Burn-Proof technology !\n"
																	"You should have installed cdrecord and mkisofs on your system in order to get\n"
																	"KOnCD working !"),
                                  I18N_NOOP("Project homepage: http://www.koncd.de"));

  aboutData.addAuthor("Kai Heitkamp",0, "koncd@kai-heitkamp.de");
  KCmdLineArgs::init( argc, argv, &aboutData );
  KCmdLineArgs::addCmdLineOptions( options );

  KApplication a;
  KOnCD *koncd = new KOnCD();
  a.setMainWidget(koncd);
  koncd->show();  

  return a.exec();
}

==> koncd-0.8.4.tar.gz: koncd-0.8.4/koncd/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : Don Mr  1 19:38:27 CET 2001
    copyright            : (C) 2001 by Kai Heitkamp
    email                : koncd@kai-heitkamp.de
 ***************************************************************************/


#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>

#include "koncd.h"

static const char *description = I18N_NOOP("KOnCD - burn your own cd's");
	
static KCmdLineOptions options[] = {
  { 0, 0, 0 }
};

int main(int argc, char *argv[]) {

  KAboutData aboutData( "koncd",
                        I18N_NOOP("KOnCD"),
                        VERSION,
                        description,
                        KAboutData::License_GPL,
                        I18N_NOOP("Developed and Copyright 2000-2001 by Kai Heitkamp"),
                        I18N_NOOP("KOnCD is a frontend to cdrecord and mkisofs, that allows you to master CDs,\n"
																	"create multisession CDs, bootable CDs and supports blanking on CD-RW.\n"
																	"It copy and master CDs on-the-fly and supports 'disc at once' mode and\n"
																	"the Burn-Proof technology ! You should have installed cdrecord and\n"
																	"mkisofs on your system in order to get KOnCD working !"),
                                  I18N_NOOP("Project homepage: http://www.koncd.de"));

  aboutData.addAuthor("Kai Heitkamp",0, "koncd@kai-heitkamp.de");
  KCmdLineArgs::init( argc, argv, &aboutData );
  KCmdLineArgs::addCmdLineOptions( options );

  KApplication a;
  KOnCD *koncd = new KOnCD();
  a.setMainWidget(koncd);
  koncd->show();  

  return a.exec();
}
